@@ -605,7 +605,7 @@ mod tests {
 
     #[test]
     fn main() {
-        for entry in fs::read_dir(Path::new(env!("CARGO_MANIFEST_DIR")).join("../../resources")).unwrap() {
+        for entry in fs::read_dir(Path::new(env!("CARGO_MANIFEST_DIR")).join("../resources")).unwrap() {
             let path = entry.unwrap().path();
             if path.extension().unwrap() != "ttf" {
                 continue;
